┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinview.h')
-rw-r--r--src/dolphinview.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/dolphinview.h b/src/dolphinview.h
index aef541a89..9b56e85a8 100644
--- a/src/dolphinview.h
+++ b/src/dolphinview.h
@@ -395,7 +395,7 @@ signals:
void sortOrderChanged(Qt::SortOrder order);
/** Is emitted if the additional information for an item has been changed. */
- void additionalInfoChanged(KFileItemDelegate::InformationList info);
+ void additionalInfoChanged(const KFileItemDelegate::InformationList& info);
/**
* Is emitted if information of an item is requested to be shown e. g. in the sidebar.
@@ -489,12 +489,12 @@ private slots:
/**
* Drops the URLs \a urls to the destination path \a destPath. If
* the URLs are dropped above an item inside the destination path,
* the item is indicated by \a destIndex. \a source
* indicates the widget where the dragging has been started from.
*/
void dropUrls(const KUrl::List& urls,
const KUrl& destPath,
- const QModelIndex& destIndex,
+ const KFileItem& destItem,
QWidget* source);
/**
@@ -516,6 +516,12 @@ private slots:
void updateSortOrder(Qt::SortOrder order);
/**
+ * Updates the view properties of the current URL to the
+ * additional informations given by \a info.
+ */
+ void updateAdditionalInfo(const KFileItemDelegate::InformationList& info);
+
+ /**
* Emits the signal contentsMoved with the current coordinates
* of the viewport as parameters.
*/
@@ -569,12 +575,6 @@ private:
QAbstractItemView* itemView() const;
/**
- * Returns true if the index is valid and represents
- * the column DolphinModel::Name.
- */
- bool isValidNameIndex(const QModelIndex& index) const;
-
- /**
* Returns true, if the item \a item has been cut into
* the clipboard.
*/
@@ -489,12 +489,12 @@ private slots:
* Drops the URLs \a urls to the destination path \a destPath. If
* the URLs are dropped above an item inside the destination path,
- * the item is indicated by \a destIndex. \a source
+ * the item is indicated by \a destItem. \a source
* indicates the widget where the dragging has been started from.
*/